Notifiers

Struct Notifiers 

pub struct Notifiers { /* private fields */ }
Notifiers allow you to create temporary event collectors, this is useful to for example wait for a user to send a message as a followup.

Every notifier waits for an event which passes its check which is returned or until the timeout is reached, returning Error::Timeout

Implementations

Source

impl Notifiers

pub async fn wait_for_event<F: Fn(&EventV1) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<EventV1, Error>

Waits for the event event to be received.

pub async fn invoke_event_waiters(&self, arg: &EventV1)

Invokes the event event.

pub async fn clear_event_waiters(&self)

Clears all waiters for the event event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_authenticated<F: Fn(&()) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(), Error>

Waits for the authenticated event to be received.

pub async fn invoke_authenticated_waiters(&self, arg: &())

Invokes the authenticated event.

pub async fn clear_authenticated_waiters(&self)

Clears all waiters for the authenticated event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_logout<F: Fn(&()) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(), Error>

Waits for the logout event to be received.

pub async fn invoke_logout_waiters(&self, arg: &())

Invokes the logout event.

pub async fn clear_logout_waiters(&self)

Clears all waiters for the logout event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_pong<F: Fn(&Ping) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<Ping, Error>

Waits for the pong event to be received.

pub async fn invoke_pong_waiters(&self, arg: &Ping)

Invokes the pong event.

pub async fn clear_pong_waiters(&self)

Clears all waiters for the pong event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_ready<F: Fn(&()) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(), Error>

Waits for the ready event to be received.

pub async fn invoke_ready_waiters(&self, arg: &())

Invokes the ready event.

pub async fn clear_ready_waiters(&self)

Clears all waiters for the ready event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_message<F: Fn(&Message) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<Message, Error>

Waits for the message event to be received.

pub async fn invoke_message_waiters(&self, arg: &Message)

Invokes the message event.

pub async fn clear_message_waiters(&self)

Clears all waiters for the message event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_message_update<F: Fn(&(Message, Message, PartialMessage, Vec<FieldsMessage>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Message, Message, PartialMessage, Vec<FieldsMessage>), Error>

Waits for the message_update event to be received.

pub async fn invoke_message_update_waiters( &self, arg: &(Message, Message, PartialMessage, Vec<FieldsMessage>), )

Invokes the message_update event.

pub async fn clear_message_update_waiters(&self)

Clears all waiters for the message_update event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_message_delete<F: Fn(&Message) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<Message, Error>

Waits for the message_delete event to be received.

pub async fn invoke_message_delete_waiters(&self, arg: &Message)

Invokes the message_delete event.

pub async fn clear_message_delete_waiters(&self)

Clears all waiters for the message_delete event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_message_react<F: Fn(&(Message, String, String)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Message, String, String), Error>

Waits for the message_react event to be received.

pub async fn invoke_message_react_waiters( &self, arg: &(Message, String, String), )

Invokes the message_react event.

pub async fn clear_message_react_waiters(&self)

Clears all waiters for the message_react event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_message_unreact<F: Fn(&(Message, String, String)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Message, String, String), Error>

Waits for the message_unreact event to be received.

pub async fn invoke_message_unreact_waiters( &self, arg: &(Message, String, String), )

Invokes the message_unreact event.

pub async fn clear_message_unreact_waiters(&self)

Clears all waiters for the message_unreact event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_message_remove_reaction<F: Fn(&(Message, String, IndexSet<String>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Message, String, IndexSet<String>), Error>

Waits for the message_remove_reaction event to be received.

pub async fn invoke_message_remove_reaction_waiters( &self, arg: &(Message, String, IndexSet<String>), )

Invokes the message_remove_reaction event.

pub async fn clear_message_remove_reaction_waiters(&self)

Clears all waiters for the message_remove_reaction event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_message_append<F: Fn(&(Message, Vec<Embed>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Message, Vec<Embed>), Error>

Waits for the message_append event to be received.

pub async fn invoke_message_append_waiters(&self, arg: &(Message, Vec<Embed>))

Invokes the message_append event.

pub async fn clear_message_append_waiters(&self)

Clears all waiters for the message_append event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_user_update<F: Fn(&(User, User, PartialUser, Vec<FieldsUser>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(User, User, PartialUser, Vec<FieldsUser>), Error>

Waits for the user_update event to be received.

pub async fn invoke_user_update_waiters( &self, arg: &(User, User, PartialUser, Vec<FieldsUser>), )

Invokes the user_update event.

pub async fn clear_user_update_waiters(&self)

Clears all waiters for the user_update event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_bulk_message_delete<F: Fn(&(String, Vec<String>, Vec<Message>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, Vec<String>, Vec<Message>), Error>

Waits for the bulk_message_delete event to be received.

pub async fn invoke_bulk_message_delete_waiters( &self, arg: &(String, Vec<String>, Vec<Message>), )

Invokes the bulk_message_delete event.

pub async fn clear_bulk_message_delete_waiters(&self)

Clears all waiters for the bulk_message_delete event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_channel_create<F: Fn(&Channel) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<Channel, Error>

Waits for the channel_create event to be received.

pub async fn invoke_channel_create_waiters(&self, arg: &Channel)

Invokes the channel_create event.

pub async fn clear_channel_create_waiters(&self)

Clears all waiters for the channel_create event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_channel_update<F: Fn(&(Channel, Channel, PartialChannel, Vec<FieldsChannel>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Channel, Channel, PartialChannel, Vec<FieldsChannel>), Error>

Waits for the channel_update event to be received.

pub async fn invoke_channel_update_waiters( &self, arg: &(Channel, Channel, PartialChannel, Vec<FieldsChannel>), )

Invokes the channel_update event.

pub async fn clear_channel_update_waiters(&self)

Clears all waiters for the channel_update event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_channel_delete<F: Fn(&Channel) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<Channel, Error>

Waits for the channel_delete event to be received.

pub async fn invoke_channel_delete_waiters(&self, arg: &Channel)

Invokes the channel_delete event.

pub async fn clear_channel_delete_waiters(&self)

Clears all waiters for the channel_delete event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_channel_group_user_join<F: Fn(&(Channel, String)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Channel, String), Error>

Waits for the channel_group_user_join event to be received.

pub async fn invoke_channel_group_user_join_waiters( &self, arg: &(Channel, String), )

Invokes the channel_group_user_join event.

pub async fn clear_channel_group_user_join_waiters(&self)

Clears all waiters for the channel_group_user_join event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_channel_group_user_leave<F: Fn(&(Channel, String)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Channel, String), Error>

Waits for the channel_group_user_leave event to be received.

pub async fn invoke_channel_group_user_leave_waiters( &self, arg: &(Channel, String), )

Invokes the channel_group_user_leave event.

pub async fn clear_channel_group_user_leave_waiters(&self)

Clears all waiters for the channel_group_user_leave event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_create<F: Fn(&(Server, Vec<Channel>, Vec<Emoji>, Vec<ChannelVoiceState>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Server, Vec<Channel>, Vec<Emoji>, Vec<ChannelVoiceState>), Error>

Waits for the server_create event to be received.

pub async fn invoke_server_create_waiters( &self, arg: &(Server, Vec<Channel>, Vec<Emoji>, Vec<ChannelVoiceState>), )

Invokes the server_create event.

pub async fn clear_server_create_waiters(&self)

Clears all waiters for the server_create event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_delete<F: Fn(&(Server, Vec<Channel>, Vec<Emoji>, Vec<ChannelVoiceState>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Server, Vec<Channel>, Vec<Emoji>, Vec<ChannelVoiceState>), Error>

Waits for the server_delete event to be received.

pub async fn invoke_server_delete_waiters( &self, arg: &(Server, Vec<Channel>, Vec<Emoji>, Vec<ChannelVoiceState>), )

Invokes the server_delete event.

pub async fn clear_server_delete_waiters(&self)

Clears all waiters for the server_delete event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_update<F: Fn(&(Server, Server, PartialServer, Vec<FieldsServer>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Server, Server, PartialServer, Vec<FieldsServer>), Error>

Waits for the server_update event to be received.

pub async fn invoke_server_update_waiters( &self, arg: &(Server, Server, PartialServer, Vec<FieldsServer>), )

Invokes the server_update event.

pub async fn clear_server_update_waiters(&self)

Clears all waiters for the server_update event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_typing_start<F: Fn(&(String, String)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, String), Error>

Waits for the typing_start event to be received.

pub async fn invoke_typing_start_waiters(&self, arg: &(String, String))

Invokes the typing_start event.

pub async fn clear_typing_start_waiters(&self)

Clears all waiters for the typing_start event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_typing_stop<F: Fn(&(String, String)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, String), Error>

Waits for the typing_stop event to be received.

pub async fn invoke_typing_stop_waiters(&self, arg: &(String, String))

Invokes the typing_stop event.

pub async fn clear_typing_stop_waiters(&self)

Clears all waiters for the typing_stop event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_member_join<F: Fn(&Member) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<Member, Error>

Waits for the server_member_join event to be received.

pub async fn invoke_server_member_join_waiters(&self, arg: &Member)

Invokes the server_member_join event.

pub async fn clear_server_member_join_waiters(&self)

Clears all waiters for the server_member_join event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_member_leave<F: Fn(&(Member, RemovalIntention)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Member, RemovalIntention), Error>

Waits for the server_member_leave event to be received.

pub async fn invoke_server_member_leave_waiters( &self, arg: &(Member, RemovalIntention), )

Invokes the server_member_leave event.

pub async fn clear_server_member_leave_waiters(&self)

Clears all waiters for the server_member_leave event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_member_update<F: Fn(&(Member, Member, PartialMember, Vec<FieldsMember>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(Member, Member, PartialMember, Vec<FieldsMember>), Error>

Waits for the server_member_update event to be received.

pub async fn invoke_server_member_update_waiters( &self, arg: &(Member, Member, PartialMember, Vec<FieldsMember>), )

Invokes the server_member_update event.

pub async fn clear_server_member_update_waiters(&self)

Clears all waiters for the server_member_update event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_role_create<F: Fn(&(String, Role)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, Role), Error>

Waits for the server_role_create event to be received.

pub async fn invoke_server_role_create_waiters(&self, arg: &(String, Role))

Invokes the server_role_create event.

pub async fn clear_server_role_create_waiters(&self)

Clears all waiters for the server_role_create event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_role_update<F: Fn(&(String, Role, Role, PartialRole, Vec<FieldsRole>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, Role, Role, PartialRole, Vec<FieldsRole>), Error>

Waits for the server_role_update event to be received.

pub async fn invoke_server_role_update_waiters( &self, arg: &(String, Role, Role, PartialRole, Vec<FieldsRole>), )

Invokes the server_role_update event.

pub async fn clear_server_role_update_waiters(&self)

Clears all waiters for the server_role_update event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_role_delete<F: Fn(&(String, Role)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, Role), Error>

Waits for the server_role_delete event to be received.

pub async fn invoke_server_role_delete_waiters(&self, arg: &(String, Role))

Invokes the server_role_delete event.

pub async fn clear_server_role_delete_waiters(&self)

Clears all waiters for the server_role_delete event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_server_role_ranks_update<F: Fn(&(String, Vec<Role>, Vec<Role>)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, Vec<Role>, Vec<Role>), Error>

Waits for the server_role_ranks_update event to be received.

pub async fn invoke_server_role_ranks_update_waiters( &self, arg: &(String, Vec<Role>, Vec<Role>), )

Invokes the server_role_ranks_update event.

pub async fn clear_server_role_ranks_update_waiters(&self)

Clears all waiters for the server_role_ranks_update event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_user_voice_state_update<F: Fn(&(UserVoiceState, UserVoiceState, PartialUserVoiceState)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(UserVoiceState, UserVoiceState, PartialUserVoiceState), Error>

Waits for the user_voice_state_update event to be received.

pub async fn invoke_user_voice_state_update_waiters( &self, arg: &(UserVoiceState, UserVoiceState, PartialUserVoiceState), )

Invokes the user_voice_state_update event.

pub async fn clear_user_voice_state_update_waiters(&self)

Clears all waiters for the user_voice_state_update event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_user_voice_channel_join<F: Fn(&(String, UserVoiceState)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, UserVoiceState), Error>

Waits for the user_voice_channel_join event to be received.

pub async fn invoke_user_voice_channel_join_waiters( &self, arg: &(String, UserVoiceState), )

Invokes the user_voice_channel_join event.

pub async fn clear_user_voice_channel_join_waiters(&self)

Clears all waiters for the user_voice_channel_join event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_user_voice_channel_move<F: Fn(&(String, String, String, UserVoiceState, UserVoiceState)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, String, String, UserVoiceState, UserVoiceState), Error>

Waits for the user_voice_channel_move event to be received.

pub async fn invoke_user_voice_channel_move_waiters( &self, arg: &(String, String, String, UserVoiceState, UserVoiceState), )

Invokes the user_voice_channel_move event.

pub async fn clear_user_voice_channel_move_waiters(&self)

Clears all waiters for the user_voice_channel_move event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_user_voice_channel_leave<F: Fn(&(String, UserVoiceState)) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<(String, UserVoiceState), Error>

Waits for the user_voice_channel_leave event to be received.

pub async fn invoke_user_voice_channel_leave_waiters( &self, arg: &(String, UserVoiceState), )

Invokes the user_voice_channel_leave event.

pub async fn clear_user_voice_channel_leave_waiters(&self)

Clears all waiters for the user_voice_channel_leave event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_emoji_create<F: Fn(&Emoji) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<Emoji, Error>

Waits for the emoji_create event to be received.

pub async fn invoke_emoji_create_waiters(&self, arg: &Emoji)

Invokes the emoji_create event.

pub async fn clear_emoji_create_waiters(&self)

Clears all waiters for the emoji_create event, this will cause them to return Error::BrokenChannel early.

pub async fn wait_for_emoji_delete<F: Fn(&Emoji) -> bool + Send + Sync + 'static>( &self, check: F, timeout: Option<Duration>, ) -> Result<Emoji, Error>

Waits for the emoji_delete event to be received.

pub async fn invoke_emoji_delete_waiters(&self, arg: &Emoji)

Invokes the emoji_delete event.

pub async fn clear_emoji_delete_waiters(&self)

Clears all waiters for the emoji_delete event, this will cause them to return Error::BrokenChannel early.

pub async fn clear_all_waiters(&self)

Clears all waiters for all events, this will cause them to return Error::BrokenChannel early.