Module types

Module types 

Structs

AllMemberResponse
Response with all members
AppendMessage
Appended Information
AutumnResponse
BanListResult
Ban list result
BannedUser
Just enough information to list a ban
Bot
Bot
BotInformation
Bot information for if the user is a bot
BotWithUserResponse
Bot with user response
BuildInformation
CaptchaFeature
Category
Channel category
ChannelCompositeKey
Composite primary key consisting of channel and user id
ChannelUnread
Channel Unread
ChannelVoiceState
Voice state for a channel
CreateServerLegacyResponse
Information returned when creating server
CreateVoiceUserResponse
Voice server token response
CreateWebhookBody
Information for the webhook
DataBanCreate
Information for new server ban
DataCreateBot
Bot Details
DataCreateEmoji
Create a new emoji
DataCreateGroup
Create new group
DataCreateRole
Information about new role to create
DataCreateServer
Information about new server to create
DataCreateServerChannel
Create new server channel
DataEditBot
New Bot Details
DataEditChannel
New webhook information
DataEditMessage
Changes to make to message
DataEditRole
New role information
DataEditRoleRanks
New role positions
DataEditServer
New server information
DataEditUser
New user information
DataEditWebhook
New webhook information
DataJoinCall
Join a voice channel
DataMemberEdit
New member information
DataMessageSearch
Options for searching for messages
DataMessageSend
Message to send
DataPermissionsValue
Data permissions Value - contains allow
DataSendFriendRequest
User lookup information
DataSetRolePermissions
New role permissions
DataSetServerRolePermission
New role permissions
DataUserProfile
New user profile data
Emoji
Emoji
Feature
FetchBotResponse
Bot Response
File
File
FlagResponse
User flag reponse
Image
Image
Interactions
Information to guide interactions on this message
Masquerade
Name and / or avatar override information
Member
Server Member
MemberCompositeKey
Composite primary key consisting of server and user id
Message
Message
MessageWebhook
Information about the webhook bundled with Message
MutualResponse
Mutual friends, servers, groups and DMs response
NewRoleResponse
Response after creating new role
OptionsBulkDelete
Options for bulk deleting messages
OptionsChannelDelete
Options when deleting a channel
OptionsFetchAllMembers
Options for fetching all members
OptionsFetchServer
Options when fetching server
OptionsFetchSettings
Options for fetching settings
OptionsQueryMessages
Options for querying messages
OptionsServerDelete
Options when leaving a server
OptionsSetSettings
Additional options for inserting settings
OptionsUnreact
Options for removing reaction
Override
Representation of a single permission override
OverrideField
Representation of a single permission override as it appears on models and in the database
OwnedBotsResponse
Owned Bots Response
PartialChannel
Partial representation of a channel
PartialMember
PartialMessage
PartialRole
PartialServer
PartialUser
PartialUserVoiceState
PartialWebhook
PermissionValue
Holds a permission value to manipulate.
PolicyChange
Platform policy change
PublicBot
Public Bot
PushNotification
Push Notification
RatelimitFailure
Relationship
Relationship entry indicating current status with other user
ReplyIntent
What this message should reply to and how
Report
User-generated platform moderation report
ResponseWebhook
Webhook information
Role
Role
SendableEmbed
Representation of a text embed before it is sent.
Server
Server
ServerBan
Server Ban
StoatConfig
StoatFeatures
SystemMessageChannels
System message channel assignments
Text
Text Embed
User
User
UserProfile
User’s profile
UserStatus
User’s active status
UserVoiceState
Voice State information for a user
Video
Video
VoiceFeature
VoiceInformation
Voice information for a channel
VoiceNode
Webhook
Webhook
WebsiteMetadata
Website metadata

Enums

BandcampType
Type of remote Bandcamp content
BotFlags
Flags that may be attributed to a bot
BulkMessageResponse
Bulk Message Response
Channel
Channel
ChannelPermission
Permission value on Revolt
ClientMessage
ContentReportReason
Reason for reporting content (message or server)
DataDefaultChannelPermissions
New default permissions
Embed
Embed
EmojiParent
Parent Id of the emoji
EventV1
Protocol Events
FetchServerResponse
Fetch server information
FieldsBot
Optional fields on bot object
FieldsChannel
Optional fields on channel object
FieldsMember
Optional fields on server member object
FieldsMessage
Optional fields on message
FieldsRole
Optional fields on server object
FieldsServer
Optional fields on server object
FieldsUser
Optional fields on user object
FieldsWebhook
Optional fields on webhook object
ImageSize
Image positioning and size
Invite
Invite
InviteBotDestination
Where we are inviting a bot to
InviteJoinResponse
Invite join response
InviteResponse
Public invite response
LegacyServerChannelType
Server Channel Type
LightspeedType
Type of remote Lightspeed.tv content
MemberResponse
Member response
MessageAuthor
Message Author Abstraction
MessageFlags
Message flag bitfield
MessageSort
Message Sort
Metadata
Metadata associated with a file
Ping
Ping Packet
Presence
Presence status
RelationshipStatus
User’s relationship with another user (or themselves)
RemovalIntention
Member removal intention
ReportStatus
Status of the report
ReportStatusString
Just the status of the report
ReportedContent
The content being reported
Special
Information about special remote content
SystemMessage
System Event
Tag
TwitchType
Type of remote Twitch content
UserBadges
User badge bitfield
UserFlags
User flag enum
UserPermission
User permission definitions
UserReportReason
Reason for reporting a user

Statics

RE_COLOUR
Regex for valid role colours
RE_DISPLAY_NAME
Regex for valid display names
RE_EMOJI
Regex for valid emoji names
RE_USERNAME
Regex for valid usernames

Traits

CheckRelationship

Type Aliases

UserSettings
HashMap of user settings Each key is mapped to a tuple consisting of the revision timestamp and serialised data (in JSON format)