pub struct PermissionValue(/* private fields */);Expand description
Holds a permission value to manipulate.
Implementations
Sourceimpl PermissionValue
impl PermissionValue
pub fn from_raw(value: u64) -> PermissionValue
pub fn into_raw(self) -> u64
Sourcepub fn revoke_all(&mut self)
pub fn revoke_all(&mut self)
Revoke all permissions
Sourcepub fn has_user_permission(&self, permission: UserPermission) -> bool
pub fn has_user_permission(&self, permission: UserPermission) -> bool
Check whether certain a user permission has been granted
Sourcepub fn has_channel_permission(&self, permission: ChannelPermission) -> bool
pub fn has_channel_permission(&self, permission: ChannelPermission) -> bool
Check whether certain a channel permission has been granted
Sourcepub fn throw_if_lacking_user_permission(
&self,
permission: UserPermission,
) -> Result<(), Error>
pub fn throw_if_lacking_user_permission( &self, permission: UserPermission, ) -> Result<(), Error>
Throw if missing user permission
Sourcepub fn throw_if_lacking_channel_permission(
&self,
permission: ChannelPermission,
) -> Result<(), Error>
pub fn throw_if_lacking_channel_permission( &self, permission: ChannelPermission, ) -> Result<(), Error>
Throw if missing channel permission
Sourcepub async fn throw_permission_override<C>(
&self,
current_value: C,
next_value: &Override,
) -> Result<(), Error>
pub async fn throw_permission_override<C>( &self, current_value: C, next_value: &Override, ) -> Result<(), Error>
Throw an error if we cannot grant permissions on either allows or denies going from the previous given value to the next given value.
We need to check any:
- allows added (permissions now granted)
- denies removed (permissions now neutral or granted)