Module utils

Module utils 

Functions

created_at
with_typing
Automatically sends typing events while the inner future is running, this is useful for displaying that the bot is still processing the users input.