pub struct Client<H> {
pub state: GlobalCache,
pub handler: Arc<H>,
pub http: HttpClient,
pub waiters: Notifiers,
pub events: Option<Events>,
}Expand description
Stoat Client
Entrypoint for connecting to the Stoat API.
Create a client via Self::new or Self::new_with_api_url if you are connecting to a 3rd party instance.
Clients require an implementation of EventHandler which contains all the event methods.
Example
While it may seem like setting up a client requires a lot, the boilerplate required here pays off in larger projects ensuring everything works smoothly together.
#[derive(Debug, Clone)]
pub enum Error {
StoatError(stoat::Error),
}
impl From<stoat::Error> for Error {
fn from(value: stoat::Error) -> Self {
Self::StoatError(value)
}
}
#[derive(Clone)]
struct Events;
#[async_trait]
impl EventHandler for Events {
type Error = Error;
async fn ready(&self, _context: Context) -> Result<(), Self::Error> {
println!("Ready!");
Ok(())
}
}
#[tokio::main]
async fn main() -> Result<(), Error> {
Client::new(Events).await?.run("TOKEN HERE").await
}Fields
state: GlobalCachehandler: Arc<H>http: HttpClientwaiters: Notifiersevents: Option<Events>Implementations
Sourceimpl<H: EventHandler + Clone + Send + Sync + 'static> Client<H>
impl<H: EventHandler + Clone + Send + Sync + 'static> Client<H>
Sourcepub async fn new(handler: H) -> Result<Self, H::Error>
pub async fn new(handler: H) -> Result<Self, H::Error>
Constructs a client with the official instance.
Use the new_with_* functions to customise the creation.
Examples found in repository?
More examples
Sourcepub async fn new_with_config(
handler: H,
config: CacheConfig,
) -> Result<Self, H::Error>
pub async fn new_with_config( handler: H, config: CacheConfig, ) -> Result<Self, H::Error>
Constructs a client with a custom cache config.
Sourcepub async fn new_with_api_url(
handler: H,
config: CacheConfig,
base_url: impl Into<String>,
) -> Result<Self, H::Error>
pub async fn new_with_api_url( handler: H, config: CacheConfig, base_url: impl Into<String>, ) -> Result<Self, H::Error>
Constructs a client with a custom Stoat instance.
Sourcepub async fn start(&mut self, token: impl Into<String>) -> Result<(), H::Error>
pub async fn start(&mut self, token: impl Into<String>) -> Result<(), H::Error>
Connects to the api and sets the current user.
You will usually not need to call this directly as Self::run handles this.
Sourcepub async fn run(&mut self, token: impl Into<String>) -> Result<(), H::Error>
pub async fn run(&mut self, token: impl Into<String>) -> Result<(), H::Error>
Connects and starts the bot, this connects to the websocket to receive events, this is the main entry point for starting the bot.
Reconnects are handled automatically.
Examples found in repository?
More examples
Sourcepub async fn handle_event(&self, event: EventV1)
pub async fn handle_event(&self, event: EventV1)
Handles a Stoat event with updating the local state, invoking notifiers and calling the event callbacks.
You shouldn’t need to call this yourself unless your mocking events or debugging.