pub struct HttpClient {
pub base: String,
pub api_config: Arc<StoatConfig>,
pub token: Option<String>,
pub user_id: Option<String>,
pub inner: Client,
pub ratelimits: Arc<HashMap<u64, RatelimitEntry>>,
}Expand description
Handles all HTTP requests to the Stoat api.
All api requests are automatically handled for rate-limits and will pause executing the request until the ratelimit is over.
Fields
base: Stringapi_config: Arc<StoatConfig>token: Option<String>user_id: Option<String>inner: Clientratelimits: Arc<HashMap<u64, RatelimitEntry>>Implementations
Sourceimpl HttpClient
impl HttpClient
Sourcepub async fn new(
base: String,
token: Option<String>,
user_id: Option<String>,
) -> Result<Self>
pub async fn new( base: String, token: Option<String>, user_id: Option<String>, ) -> Result<Self>
Creates a new instance of HttpClient
You should not need to create your own instance of HttpClient usually as its handled automatically by Client
but this can be useful for webhooks and one-off requests outside of running a client.
Sourcepub fn request(&self, method: Method, route: impl AsRef<str>) -> HttpRequest
pub fn request(&self, method: Method, route: impl AsRef<str>) -> HttpRequest
Creates a raw http request for a specific method and route.
Sourcepub fn autumn_request(
&self,
method: Method,
route: impl AsRef<str>,
) -> HttpRequest
pub fn autumn_request( &self, method: Method, route: impl AsRef<str>, ) -> HttpRequest
Creates a raw autumn http request for a specific method and route.
Sourcepub fn format_file_url(
&self,
tag: &str,
id: &str,
filename: Option<&str>,
) -> String
pub fn format_file_url( &self, tag: &str, id: &str, filename: Option<&str>, ) -> String
Formats a url string for a file hosted on Stoat.
pub async fn get_root(&self) -> Result<StoatConfig>
pub async fn send_message( &self, channel_id: &str, data: &DataMessageSend, ) -> Result<Message>
pub async fn fetch_user(&self, user_id: &str) -> Result<User>
pub async fn fetch_messages<'a>( &self, channel_id: &str, data: &OptionsQueryMessages, ) -> Result<BulkMessageResponse>
pub async fn open_dm(&self, user_id: &str) -> Result<Channel>
pub async fn fetch_member( &self, server_id: &str, user_id: &str, ) -> Result<Member>
pub async fn delete_message( &self, channel_id: &str, message_id: &str, ) -> Result<()>
pub async fn edit_message( &self, channel_id: &str, message_id: &str, data: &DataEditMessage, ) -> Result<Message>
pub async fn join_call( &self, channel_id: &str, data: &DataJoinCall, ) -> Result<CreateVoiceUserResponse>
pub async fn fetch_message( &self, channel_id: &str, message_id: &str, ) -> Result<Message>
pub async fn upload_file( &self, tag: &str, file: LocalFile, ) -> Result<AutumnResponse>
pub async fn delete_channel(&self, channel_id: &str) -> Result<()>
pub async fn edit_channel( &self, channel_id: &str, data: &DataEditChannel, ) -> Result<Channel>
pub async fn fetch_channel(&self, channel_id: &str) -> Result<Channel>
pub async fn fetch_members(&self, channel_id: &str) -> Result<Vec<User>>
pub async fn delete_messages( &self, channel_id: &str, options: &OptionsBulkDelete, ) -> Result<()>
pub async fn clear_reactions( &self, channel_id: &str, message_id: &str, ) -> Result<()>
pub async fn pin_message( &self, channel_id: &str, message_id: &str, ) -> Result<Message>
pub async fn unpin_message( &self, channel_id: &str, message_id: &str, ) -> Result<Message>
pub async fn react_message( &self, channel_id: &str, message_id: &str, emoji: &str, ) -> Result<()>
pub async fn unreact_message( &self, channel_id: &str, message_id: &str, emoji: &str, options: &OptionsUnreact, ) -> Result<()>
pub async fn set_default_channel_permissions( &self, channel_id: &str, data: &DataDefaultChannelPermissions, ) -> Result<Channel>
pub async fn set_role_channel_permissions( &self, channel_id: &str, role_id: &str, data: &DataSetRolePermissions, ) -> Result<Channel>
pub async fn create_webhook( &self, channel_id: &str, data: &CreateWebhookBody, ) -> Result<Webhook>
pub async fn fetch_webhooks(&self, channel_id: &str) -> Result<Vec<Webhook>>
pub async fn delete_invite(&self, invite_id: &str) -> Result<()>
pub async fn fetch_invite(&self, invite_id: &str) -> Result<Invite>
pub async fn ban_member( &self, server_id: &str, user_id: &str, data: &DataBanCreate, ) -> Result<ServerBan>
pub async fn fetch_bans(&self, server_id: &str) -> Result<BanListResult>
pub async fn unban_member(&self, server_id: &str, user_id: &str) -> Result<()>
pub async fn create_channel( &self, server_id: &str, data: &DataCreateServerChannel, ) -> Result<Channel>
pub async fn fetch_emojis(&self, server_id: &str) -> Result<Vec<Emoji>>
pub async fn fetch_invites(&self, server_id: &str) -> Result<Vec<Invite>>
pub async fn edit_member( &self, server_id: &str, user_id: &str, data: &DataMemberEdit, ) -> Result<Member>
pub async fn kick_member(&self, server_id: &str, user_id: &str) -> Result<()>
pub async fn set_default_server_permissions( &self, server_id: &str, data: &DataPermissionsValue, ) -> Result<Server>
pub async fn set_role_server_permissions( &self, server_id: &str, role_id: &str, data: &DataSetServerRolePermission, ) -> Result<Server>
pub async fn create_role( &self, server_id: &str, data: &DataCreateRole, ) -> Result<NewRoleResponse>
pub async fn delete_role(&self, server_id: &str, role_id: &str) -> Result<()>
pub async fn edit_role_positions( &self, server_id: &str, data: &DataEditRoleRanks, ) -> Result<Server>
pub async fn edit_role( &self, server_id: &str, role_id: &str, data: &DataEditRole, ) -> Result<Role>
pub async fn fetch_role(&self, server_id: &str, role_id: &str) -> Result<Role>
pub async fn delete_server( &self, server_id: &str, options: &OptionsServerDelete, ) -> Result<()>
pub async fn edit_server( &self, server_id: &str, data: &DataEditServer, ) -> Result<Server>
pub async fn fetch_server( &self, server_id: &str, options: &OptionsFetchServer, ) -> Result<FetchServerResponse>
pub async fn edit_user( &self, user_id: &str, data: &DataEditUser, ) -> Result<User>
pub async fn fetch_dms(&self) -> Result<Vec<Channel>>
pub async fn fetch_user_profile(&self, user_id: &str) -> Result<UserProfile>
pub async fn fetch_self(&self) -> Result<User>
pub async fn fetch_user_flags(&self, user_id: &str) -> Result<FlagResponse>
pub async fn fetch_user_mutuals(&self, user_id: &str) -> Result<MutualResponse>
pub async fn fetch_default_avatar(&self, user_id: &str) -> Result<Bytes>
pub async fn fetch_image_preview(&self, tag: &str, id: &str) -> Result<Bytes>
pub async fn fetch_image( &self, tag: &str, id: &str, filename: &str, ) -> Result<Bytes>
pub async fn fetch_webhook(&self, webhook_id: &str) -> Result<ResponseWebhook>
pub async fn fetch_webhook_token( &self, webhook_id: &str, token: &str, ) -> Result<Webhook>
pub async fn edit_webhook( &self, webhook_id: &str, data: &DataEditWebhook, ) -> Result<Webhook>
pub async fn edit_webhook_token( &self, webhook_id: &str, data: &DataEditWebhook, token: &str, ) -> Result<Webhook>
pub async fn delete_webhook(&self, webhook_id: &str) -> Result<()>
pub async fn delete_webhook_token( &self, webhook_id: &str, token: &str, ) -> Result<()>
pub async fn execute_webhook_token( &self, webhook_id: &str, token: &str, data: &DataMessageSend, ) -> Result<Message>