Structs
- AllMember
Response - Response with all members
- Append
Message - Appended Information
- Autumn
Response - BanList
Result - Ban list result
- Banned
User - Just enough information to list a ban
- Bot
- Bot
- BotInformation
- Bot information for if the user is a bot
- BotWith
User Response - Bot with user response
- Build
Information - Captcha
Feature - Category
- Channel category
- Channel
Composite Key - Composite primary key consisting of channel and user id
- Channel
Unread - Channel Unread
- Channel
Voice State - Voice state for a channel
- Create
Server Legacy Response - Information returned when creating server
- Create
Voice User Response - Voice server token response
- Create
Webhook Body - Information for the webhook
- Data
BanCreate - Information for new server ban
- Data
Create Bot - Bot Details
- Data
Create Emoji - Create a new emoji
- Data
Create Group - Create new group
- Data
Create Role - Information about new role to create
- Data
Create Server - Information about new server to create
- Data
Create Server Channel - Create new server channel
- Data
Edit Bot - New Bot Details
- Data
Edit Channel - New webhook information
- Data
Edit Message - Changes to make to message
- Data
Edit Role - New role information
- Data
Edit Role Ranks - New role positions
- Data
Edit Server - New server information
- Data
Edit User - New user information
- Data
Edit Webhook - New webhook information
- Data
Join Call - Join a voice channel
- Data
Member Edit - New member information
- Data
Message Search - Options for searching for messages
- Data
Message Send - Message to send
- Data
Permissions Value - Data permissions Value - contains allow
- Data
Send Friend Request - User lookup information
- Data
SetRole Permissions - New role permissions
- Data
SetServer Role Permission - New role permissions
- Data
User Profile - New user profile data
- Emoji
- Emoji
- Feature
- Fetch
BotResponse - Bot Response
- File
- File
- Flag
Response - User flag reponse
- Image
- Image
- Interactions
- Information to guide interactions on this message
- Masquerade
- Name and / or avatar override information
- Member
- Server Member
- Member
Composite Key - Composite primary key consisting of server and user id
- Message
- Message
- Message
Webhook - Information about the webhook bundled with Message
- Mutual
Response - Mutual friends, servers, groups and DMs response
- NewRole
Response - Response after creating new role
- Options
Bulk Delete - Options for bulk deleting messages
- Options
Channel Delete - Options when deleting a channel
- Options
Fetch AllMembers - Options for fetching all members
- Options
Fetch Server - Options when fetching server
- Options
Fetch Settings - Options for fetching settings
- Options
Query Messages - Options for querying messages
- Options
Server Delete - Options when leaving a server
- Options
SetSettings - Additional options for inserting settings
- Options
Unreact - Options for removing reaction
- Override
- Representation of a single permission override
- Override
Field - Representation of a single permission override as it appears on models and in the database
- Owned
Bots Response - Owned Bots Response
- Partial
Channel - Partial representation of a channel
- Partial
Member - Partial
Message - Partial
Role - Partial
Server - Partial
User - Partial
User Voice State - Partial
Webhook - Permission
Value - Holds a permission value to manipulate.
- Policy
Change - Platform policy change
- Public
Bot - Public Bot
- Push
Notification - Push Notification
- Ratelimit
Failure - Relationship
- Relationship entry indicating current status with other user
- Reply
Intent - What this message should reply to and how
- Report
- User-generated platform moderation report
- Response
Webhook - Webhook information
- Role
- Role
- Sendable
Embed - Representation of a text embed before it is sent.
- Server
- Server
- Server
Ban - Server Ban
- Stoat
Config - Stoat
Features - System
Message Channels - System message channel assignments
- Text
- Text Embed
- User
- User
- User
Profile - User’s profile
- User
Status - User’s active status
- User
Voice State - Voice State information for a user
- Video
- Video
- Voice
Feature - Voice
Information - Voice information for a channel
- Voice
Node - Webhook
- Webhook
- Website
Metadata - Website metadata
Enums
- Bandcamp
Type - Type of remote Bandcamp content
- BotFlags
- Flags that may be attributed to a bot
- Bulk
Message Response - Bulk Message Response
- Channel
- Channel
- Channel
Permission - Permission value on Revolt
- Client
Message - Content
Report Reason - Reason for reporting content (message or server)
- Data
Default Channel Permissions - New default permissions
- Embed
- Embed
- Emoji
Parent - Parent Id of the emoji
- EventV1
- Protocol Events
- Fetch
Server Response - Fetch server information
- Fields
Bot - Optional fields on bot object
- Fields
Channel - Optional fields on channel object
- Fields
Member - Optional fields on server member object
- Fields
Message - Optional fields on message
- Fields
Role - Optional fields on server object
- Fields
Server - Optional fields on server object
- Fields
User - Optional fields on user object
- Fields
Webhook - Optional fields on webhook object
- Image
Size - Image positioning and size
- Invite
- Invite
- Invite
BotDestination - Where we are inviting a bot to
- Invite
Join Response - Invite join response
- Invite
Response - Public invite response
- Legacy
Server Channel Type - Server Channel Type
- Lightspeed
Type - Type of remote Lightspeed.tv content
- Member
Response - Member response
- Message
Author - Message Author Abstraction
- Message
Flags - Message flag bitfield
- Message
Sort - Message Sort
- Metadata
- Metadata associated with a file
- Ping
- Ping Packet
- Presence
- Presence status
- Relationship
Status - User’s relationship with another user (or themselves)
- Removal
Intention - Member removal intention
- Report
Status - Status of the report
- Report
Status String - Just the status of the report
- Reported
Content - The content being reported
- Special
- Information about special remote content
- System
Message - System Event
- Tag
- Twitch
Type - Type of remote Twitch content
- User
Badges - User badge bitfield
- User
Flags - User flag enum
- User
Permission - User permission definitions
- User
Report Reason - Reason for reporting a user
Statics
- RE_
COLOUR - Regex for valid role colours
- RE_
DISPLAY_ NAME - Regex for valid display names
- RE_
EMOJI - Regex for valid emoji names
- RE_
USERNAME - Regex for valid usernames
Traits
Type Aliases
- User
Settings - HashMap of user settings Each key is mapped to a tuple consisting of the revision timestamp and serialised data (in JSON format)