PermissionValue

Struct PermissionValue 

pub struct PermissionValue(/* private fields */);
Holds a permission value to manipulate.

Implementations

Source

impl PermissionValue

pub fn from_raw(value: u64) -> PermissionValue

pub fn into_raw(self) -> u64

pub fn apply(&mut self, v: Override)

Apply a given override to this value

pub fn allow(&mut self, v: u64)

Allow given permissions

pub fn revoke(&mut self, v: u64)

Revoke given permissions

pub fn revoke_all(&mut self)

Revoke all permissions

pub fn restrict(&mut self, v: u64)

Restrict to given permissions

pub fn has(&self, v: u64) -> bool

Check whether certain a permission has been granted

pub fn has_user_permission(&self, permission: UserPermission) -> bool

Check whether certain a user permission has been granted

pub fn has_channel_permission(&self, permission: ChannelPermission) -> bool

Check whether certain a channel permission has been granted

pub fn throw_if_lacking_user_permission( &self, permission: UserPermission, ) -> Result<(), Error>

Throw if missing user permission

pub fn throw_if_lacking_channel_permission( &self, permission: ChannelPermission, ) -> Result<(), Error>

Throw if missing channel permission

pub async fn throw_permission_override<C>( &self, current_value: C, next_value: &Override, ) -> Result<(), Error>
where C: Into<Option<Override>>,

Throw an error if we cannot grant permissions on either allows or denies going from the previous given value to the next given value.

We need to check any:

  • allows added (permissions now granted)
  • denies removed (permissions now neutral or granted)